/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'eo', {
	border: 'Montri borderon de kadro (frame)',
	noUrl: 'Bonvolu entajpi la retadreson de la ligilo al la enlinia kadro (IFrame)',
	scrolling: 'Ebligi rulumskalon',
	title: 'Atributoj de la enlinia kadro (IFrame)',
	toolbar: 'Enlinia kadro (IFrame)',
	tabindex: 'Remove from tabindex' // MISSING
} );
